HexToColorModel class

Constructors

HexToColorModel({String? hex, String? color})
HexToColorModel.fromJson(Map<String, dynamic> json)
factory

Properties

color ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hex ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? hex, String? color}) → HexToColorModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited